==> mingw-w64-clang-aarch64-glfw-3.3.9-1-any.pkg.tar.zst: clangarm64/share/doc/glfw/html/search/all_6.js <==
var searchData=
[
  ['c_20on_20windows_0',['With MinGW or Visual C++ on Windows',['../build_guide.html#build_link_win32',1,'']]],
  ['callback_1',['callback',['../news.html#news_31_charmods',1,'Character with modifiers callback'],['../news.html#charmods_callback_33',1,'Character with modifiers callback'],['../news.html#news_30_enterleave',1,'Cursor enter/leave callback'],['../news.html#news_30_error',1,'Error callback'],['../news.html#news_32_joystick',1,'Joystick connection callback'],['../quick_guide.html#quick_capture_error',1,'Setting an error callback'],['../news.html#news_30_focusfun',1,'Window focus callback'],['../news.html#news_30_iconifyfun',1,'Window iconification callback'],['../news.html#maximize_33',1,'Window maximization callback'],['../news.html#news_30_wndposfun',1,'Window position callback']]],
  ['capture_20of_20system_20wide_20hotkeys_2',['Capture of system-wide hotkeys',['../moving_guide.html#moving_syskeys',1,'']]],
  ['caveats_20for_20version_203_203_3',['Caveats for version 3.3',['../news.html#caveats_33',1,'']]],
  ['centering_20window_20hint_4',['Cursor centering window hint',['../news.html#center_cursor_33',1,'']]],
  ['change_20tables_5',['Name change tables',['../moving_guide.html#moving_tables',1,'']]],
  ['changed_6',['Layout of joysticks have changed',['../news.html#joystick_layout_33',1,'']]],
  ['changed_20and_20removed_20features_7',['Changed and removed features',['../moving_guide.html#moving_removed',1,'']]],
  ['changes_8',['changes',['../moving_guide.html#moving_cursorpos',1,'Cursor position changes'],['../input_guide.html#joystick_event',1,'Joystick configuration changes'],['../moving_guide.html#moving_joystick',1,'Joystick function changes'],['../monitor_guide.html#monitor_event',1,'Monitor configuration changes'],['../moving_guide.html#moving_window_close',1,'Window closing changes']]],
  ['channel_20on_20older_20wayland_20systems_9',['Frambuffer may lack alpha channel on older Wayland systems',['../news.html#wayland_alpha_34',1,'']]],
  ['character_20actions_10',['Removal of character actions',['../moving_guide.html#moving_char_up',1,'']]],
  ['character_20with_20modifiers_20callback_11',['character with modifiers callback',['../news.html#charmods_callback_33',1,'Character with modifiers callback'],['../news.html#news_31_charmods',1,'Character with modifiers callback']]],
  ['checking_20for_20extensions_12',['Checking for extensions',['../context_guide.html#context_glext_string',1,'']]],
  ['checking_20the_20window_20close_20flag_13',['Checking the window close flag',['../quick_guide.html#quick_window_close',1,'']]],
  ['clipboard_20functions_14',['Window parameter to clipboard functions',['../news.html#clipboard_window_33',1,'']]],
  ['clipboard_20input_20and_20output_15',['Clipboard input and output',['../input_guide.html#clipboard',1,'']]],
  ['clipboard_20text_20i_20o_16',['Clipboard text I/O',['../news.html#news_30_clipboard',1,'']]],
  ['clipboard_20transfer_20limits_17',['X11 clipboard transfer limits',['../news.html#x11_clipboard_33',1,'']]],
  ['close_20flag_18',['close flag',['../quick_guide.html#quick_window_close',1,'Checking the window close flag'],['../window_guide.html#window_close',1,'Window closing and close flag']]],
  ['closing_20and_20close_20flag_19',['Window closing and close flag',['../window_guide.html#window_close',1,'']]],
  ['closing_20changes_20',['Window closing changes',['../moving_guide.html#moving_window_close',1,'']]],
  ['cmake_21',['cmake',['../compile_guide.html#compile_generate',1,'Generating build files with CMake'],['../compile_guide.html#compile_cmake',1,'Using CMake']]],
  ['cmake_203_200_20or_20later_20is_20required_22',['CMake 3.0 or later is required',['../news.html#cmake_version_33',1,'']]],
  ['cmake_20and_20glfw_20source_23',['With CMake and GLFW source',['../build_guide.html#build_link_cmake_source',1,'']]],
  ['cmake_20and_20installed_20glfw_20binaries_24',['With CMake and installed GLFW binaries',['../build_guide.html#build_link_cmake_package',1,'']]],
  ['cmake_20and_20mingw_25',['Cross-compilation with CMake and MinGW',['../compile_guide.html#compile_mingw_cross',1,'']]],
  ['cmake_20build_20system_26',['CMake build system',['../news.html#news_30_cmake',1,'']]],
  ['cmake_20command_20line_20tool_27',['Generating files with the CMake command-line tool',['../compile_guide.html#compile_generate_cli',1,'']]],
  ['cmake_20config_20file_20package_20support_28',['CMake config-file package support',['../news.html#news_32_cmake',1,'']]],
  ['cmake_20gui_29',['Generating files with the CMake GUI',['../compile_guide.html#compile_generate_gui',1,'']]],
  ['cmake_20option_20lib_5fsuffix_30',['CMake option LIB_SUFFIX',['../news.html#lib_suffix_33',1,'']]],
  ['cmake_20options_31',['cmake options',['../compile_guide.html#compile_options',1,'CMake options'],['../compile_guide.html#compile_options_shared',1,'Shared CMake options'],['../compile_guide.html#compile_options_wayland',1,'Wayland specific CMake options'],['../compile_guide.html#compile_options_win32',1,'Windows specific CMake options']]],
  ['cmake_20options_20and_20macros_32',['macOS specific CMake options and macros',['../news.html#macos_options_33',1,'']]],
  ['codes_33',['Error codes',['../group__errors.html',1,'']]],
  ['command_20line_20on_20macos_34',['With command-line on macOS',['../build_guide.html#build_link_osx',1,'']]],
  ['command_20line_20tool_35',['Generating files with the CMake command-line tool',['../compile_guide.html#compile_generate_cli',1,'']]],
  ['compat_2edox_36',['compat.dox',['../compat_8dox.html',1,'']]],
  ['compatibility_37',['Version compatibility',['../intro_guide.html#compatibility',1,'']]],
  ['compilation_20with_20cmake_20and_20mingw_38',['Cross-compilation with CMake and MinGW',['../compile_guide.html#compile_mingw_cross',1,'']]],
  ['compile_20time_20version_39',['Compile-time version',['../intro_guide.html#intro_version_compile',1,'']]],
  ['compile_2edox_40',['compile.dox',['../compile_8dox.html',1,'']]],
  ['compiling_20glfw_41',['Compiling GLFW',['../compile_guide.html',1,'']]],
  ['compiling_20glfw_20manually_42',['Compiling GLFW manually',['../compile_guide.html#compile_manual',1,'']]],
  ['compiling_20the_20library_43',['Compiling the library',['../compile_guide.html#compile_compile',1,'']]],
  ['config_20file_20package_20support_44',['CMake config-file package support',['../news.html#news_32_cmake',1,'']]],
  ['config_20on_20unix_45',['With makefiles and pkg-config on Unix',['../build_guide.html#build_link_pkgconfig',1,'']]],
  ['configuration_20changes_46',['configuration changes',['../input_guide.html#joystick_event',1,'Joystick configuration changes'],['../monitor_guide.html#monitor_event',1,'Monitor configuration changes']]],
  ['configuration_20macros_47',['Configuration macros',['../internals_guide.html#internals_config',1,'']]],
  ['conformance_48',['Standards conformance',['../compat_guide.html',1,'']]],
  ['connection_20callback_49',['Joystick connection callback',['../news.html#news_32_joystick',1,'']]],
  ['constants_20in_20version_203_203_50',['New constants in version 3.3',['../news.html#constants_33',1,'']]],
  ['constraints_51',['Hard and soft constraints',['../window_guide.html#window_hints_hard',1,'']]],
  ['content_20scale_52',['content scale',['../monitor_guide.html#monitor_scale',1,'Content scale'],['../window_guide.html#window_scale',1,'Window content scale']]],
  ['content_20scale_20queries_20for_20dpi_20aware_20rendering_53',['Content scale queries for DPI-aware rendering',['../news.html#content_scale_33',1,'']]],
  ['context_54',['context',['../quick_guide.html#quick_create_window',1,'Creating a window and context'],['../context_guide.html#context_current',1,'Current context']]],
  ['context_20creation_55',['Error-free context creation',['../news.html#news_32_noerror',1,'']]],
  ['context_20creation_20api_20selection_56',['Run-time context creation API selection',['../news.html#news_32_contextapi',1,'']]],
  ['context_20creation_20extensions_57',['Support for more context creation extensions',['../news.html#glext_33',1,'']]],
  ['context_20creation_20hints_58',['Context creation hints',['../context_guide.html#context_hints',1,'']]],
  ['context_20creation_20support_59',['OSMesa off-screen context creation support',['../news.html#osmesa_33',1,'']]],
  ['context_20current_60',['Making the OpenGL context current',['../quick_guide.html#quick_context_current',1,'']]],
  ['context_20guide_61',['Context guide',['../context_guide.html',1,'']]],
  ['context_20less_20windows_62',['Context-less windows',['../news.html#news_32_noapi',1,'']]],
  ['context_20management_63',['Explicit context management',['../moving_guide.html#moving_context',1,'']]],
  ['context_20object_20sharing_64',['Context object sharing',['../context_guide.html#context_sharing',1,'']]],
  ['context_20objects_65',['Context objects',['../context_guide.html#context_object',1,'']]],
  ['context_20reference_66',['Context reference',['../group__context.html',1,'']]],
  ['context_20related_20attributes_67',['Context related attributes',['../window_guide.html#window_attribs_ctx',1,'']]],
  ['context_20related_20hints_68',['Context related hints',['../window_guide.html#window_hints_ctx',1,'']]],
  ['context_20release_20behaviors_69',['Context release behaviors',['../news.html#news_31_release',1,'']]],
  ['context_2edox_70',['context.dox',['../context_8dox.html',1,'']]],
  ['contexts_71',['contexts',['../context_guide.html#context_offscreen',1,'Offscreen contexts'],['../context_guide.html#context_less',1,'Windows without contexts']]],
  ['control_72',['Window input focus control',['../news.html#news_32_focus',1,'']]],
  ['coordinate_20systems_73',['Coordinate systems',['../intro_guide.html#coordinate_systems',1,'']]],
  ['creating_20a_20vulkan_20window_20surface_74',['Creating a Vulkan window surface',['../vulkan_guide.html#vulkan_surface',1,'']]],
  ['creating_20a_20window_20and_20context_75',['Creating a window and context',['../quick_guide.html#quick_create_window',1,'']]],
  ['creating_20the_20window_76',['Creating the window',['../vulkan_guide.html#vulkan_window',1,'']]],
  ['creation_77',['creation',['../input_guide.html#cursor_custom',1,'Custom cursor creation'],['../news.html#news_32_noerror',1,'Error-free context creation'],['../input_guide.html#cursor_standard',1,'Standard cursor creation'],['../window_guide.html#window_creation',1,'Window creation']]],
  ['creation_20api_20selection_78',['Run-time context creation API selection',['../news.html#news_32_contextapi',1,'']]],
  ['creation_20extensions_79',['Support for more context creation extensions',['../news.html#glext_33',1,'']]],
  ['creation_20hints_80',['creation hints',['../context_guide.html#context_hints',1,'Context creation hints'],['../window_guide.html#window_hints',1,'Window creation hints']]],
  ['creation_20support_81',['OSMesa off-screen context creation support',['../news.html#osmesa_33',1,'']]],
  ['cross_20compilation_20with_20cmake_20and_20mingw_82',['Cross-compilation with CMake and MinGW',['../compile_guide.html#compile_mingw_cross',1,'']]],
  ['current_83',['Making the OpenGL context current',['../quick_guide.html#quick_context_current',1,'']]],
  ['current_20context_84',['Current context',['../context_guide.html#context_current',1,'']]],
  ['cursor_20centering_20window_20hint_85',['Cursor centering window hint',['../news.html#center_cursor_33',1,'']]],
  ['cursor_20creation_86',['cursor creation',['../input_guide.html#cursor_custom',1,'Custom cursor creation'],['../input_guide.html#cursor_standard',1,'Standard cursor creation']]],
  ['cursor_20destruction_87',['Cursor destruction',['../input_guide.html#cursor_destruction',1,'']]],
  ['cursor_20enter_20leave_20callback_88',['Cursor enter/leave callback',['../news.html#news_30_enterleave',1,'']]],
  ['cursor_20enter_20leave_20events_89',['Cursor enter/leave events',['../input_guide.html#cursor_enter',1,'']]],
  ['cursor_20hover_20window_20attribute_90',['Mouse cursor hover window attribute',['../news.html#cursor_hover_33',1,'']]],
  ['cursor_20images_91',['Custom mouse cursor images',['../news.html#news_31_cursor',1,'']]],
  ['cursor_20mode_92',['Cursor mode',['../input_guide.html#cursor_mode',1,'']]],
  ['cursor_20objects_93',['Cursor objects',['../input_guide.html#cursor_object',1,'']]],
  ['cursor_20position_94',['cursor position',['../input_guide.html#cursor_pos',1,'Cursor position'],['../news.html#news_31_direct',1,'Direct access for window attributes and cursor position']]],
  ['cursor_20position_20changes_95',['Cursor position changes',['../moving_guide.html#moving_cursorpos',1,'']]],
  ['cursor_20setting_96',['Cursor setting',['../input_guide.html#cursor_set',1,'']]],
  ['cursor_20shapes_97',['Standard cursor shapes',['../group__shapes.html',1,'']]],
  ['custom_20cursor_20creation_98',['Custom cursor creation',['../input_guide.html#cursor_custom',1,'']]],
  ['custom_20mouse_20cursor_20images_99',['Custom mouse cursor images',['../news.html#news_31_cursor',1,'']]]
];

==> mingw-w64-clang-aarch64-glfw-3.3.9-2-any.pkg.tar.zst: clangarm64/share/doc/glfw/html/search/all_6.js <==
var searchData=
[
  ['c_20on_20windows_0',['With MinGW or Visual C++ on Windows',['../build_guide.html#build_link_win32',1,'']]],
  ['callback_1',['Callback',['../news.html#charmods_callback_33',1,'Character with modifiers callback'],['../news.html#news_31_charmods',1,'Character with modifiers callback'],['../news.html#news_30_enterleave',1,'Cursor enter/leave callback'],['../news.html#news_30_error',1,'Error callback'],['../news.html#news_32_joystick',1,'Joystick connection callback'],['../quick_guide.html#quick_capture_error',1,'Setting an error callback'],['../news.html#news_30_focusfun',1,'Window focus callback'],['../news.html#news_30_iconifyfun',1,'Window iconification callback'],['../news.html#maximize_33',1,'Window maximization callback'],['../news.html#news_30_wndposfun',1,'Window position callback']]],
  ['capture_20of_20system_20wide_20hotkeys_2',['Capture of system-wide hotkeys',['../moving_guide.html#moving_syskeys',1,'']]],
  ['caveats_20for_20version_203_203_3',['Caveats for version 3.3',['../news.html#caveats_33',1,'']]],
  ['centering_20window_20hint_4',['Cursor centering window hint',['../news.html#center_cursor_33',1,'']]],
  ['change_20tables_5',['Name change tables',['../moving_guide.html#moving_tables',1,'']]],
  ['changed_6',['Layout of joysticks have changed',['../news.html#joystick_layout_33',1,'']]],
  ['changed_20and_20removed_20features_7',['Changed and removed features',['../moving_guide.html#moving_removed',1,'']]],
  ['changes_8',['Changes',['../moving_guide.html#moving_cursorpos',1,'Cursor position changes'],['../input_guide.html#joystick_event',1,'Joystick configuration changes'],['../moving_guide.html#moving_joystick',1,'Joystick function changes'],['../monitor_guide.html#monitor_event',1,'Monitor configuration changes'],['../moving_guide.html#moving_window_close',1,'Window closing changes']]],
  ['channel_20on_20older_20wayland_20systems_9',['Frambuffer may lack alpha channel on older Wayland systems',['../news.html#wayland_alpha_34',1,'']]],
  ['character_20actions_10',['Removal of character actions',['../moving_guide.html#moving_char_up',1,'']]],
  ['character_20with_20modifiers_20callback_11',['Character with modifiers callback',['../news.html#charmods_callback_33',1,'Character with modifiers callback'],['../news.html#news_31_charmods',1,'Character with modifiers callback']]],
  ['checking_20for_20extensions_12',['Checking for extensions',['../context_guide.html#context_glext_string',1,'']]],
  ['checking_20the_20window_20close_20flag_13',['Checking the window close flag',['../quick_guide.html#quick_window_close',1,'']]],
  ['clipboard_20functions_14',['Window parameter to clipboard functions',['../news.html#clipboard_window_33',1,'']]],
  ['clipboard_20input_20and_20output_15',['Clipboard input and output',['../input_guide.html#clipboard',1,'']]],
  ['clipboard_20text_20i_20o_16',['Clipboard text I/O',['../news.html#news_30_clipboard',1,'']]],
  ['clipboard_20transfer_20limits_17',['X11 clipboard transfer limits',['../news.html#x11_clipboard_33',1,'']]],
  ['close_20flag_18',['Close flag',['../quick_guide.html#quick_window_close',1,'Checking the window close flag'],['../window_guide.html#window_close',1,'Window closing and close flag']]],
  ['closing_20and_20close_20flag_19',['Window closing and close flag',['../window_guide.html#window_close',1,'']]],
  ['closing_20changes_20',['Window closing changes',['../moving_guide.html#moving_window_close',1,'']]],
  ['cmake_21',['CMake',['../compile_guide.html#compile_generate',1,'Generating build files with CMake'],['../compile_guide.html#compile_cmake',1,'Using CMake']]],
  ['cmake_203_200_20or_20later_20is_20required_22',['CMake 3.0 or later is required',['../news.html#cmake_version_33',1,'']]],
  ['cmake_20and_20glfw_20source_23',['With CMake and GLFW source',['../build_guide.html#build_link_cmake_source',1,'']]],
  ['cmake_20and_20installed_20glfw_20binaries_24',['With CMake and installed GLFW binaries',['../build_guide.html#build_link_cmake_package',1,'']]],
  ['cmake_20and_20mingw_25',['Cross-compilation with CMake and MinGW',['../compile_guide.html#compile_mingw_cross',1,'']]],
  ['cmake_20build_20system_26',['CMake build system',['../news.html#news_30_cmake',1,'']]],
  ['cmake_20command_20line_20tool_27',['Generating files with the CMake command-line tool',['../compile_guide.html#compile_generate_cli',1,'']]],
  ['cmake_20config_20file_20package_20support_28',['CMake config-file package support',['../news.html#news_32_cmake',1,'']]],
  ['cmake_20gui_29',['Generating files with the CMake GUI',['../compile_guide.html#compile_generate_gui',1,'']]],
  ['cmake_20option_20lib_5fsuffix_30',['CMake option LIB_SUFFIX',['../news.html#lib_suffix_33',1,'']]],
  ['cmake_20options_31',['CMake options',['../compile_guide.html#compile_options',1,'CMake options'],['../compile_guide.html#compile_options_shared',1,'Shared CMake options'],['../compile_guide.html#compile_options_wayland',1,'Wayland specific CMake options'],['../compile_guide.html#compile_options_win32',1,'Windows specific CMake options']]],
  ['cmake_20options_20and_20macros_32',['macOS specific CMake options and macros',['../news.html#macos_options_33',1,'']]],
  ['codes_33',['Error codes',['../group__errors.html',1,'']]],
  ['command_20line_20on_20macos_34',['With command-line on macOS',['../build_guide.html#build_link_osx',1,'']]],
  ['command_20line_20tool_35',['Generating files with the CMake command-line tool',['../compile_guide.html#compile_generate_cli',1,'']]],
  ['compat_2edox_36',['compat.dox',['../compat_8dox.html',1,'']]],
  ['compatibility_37',['Version compatibility',['../intro_guide.html#compatibility',1,'']]],
  ['compilation_20with_20cmake_20and_20mingw_38',['Cross-compilation with CMake and MinGW',['../compile_guide.html#compile_mingw_cross',1,'']]],
  ['compile_20time_20version_39',['Compile-time version',['../intro_guide.html#intro_version_compile',1,'']]],
  ['compile_2edox_40',['compile.dox',['../compile_8dox.html',1,'']]],
  ['compiling_20glfw_41',['Compiling GLFW',['../compile_guide.html',1,'']]],
  ['compiling_20glfw_20manually_42',['Compiling GLFW manually',['../compile_guide.html#compile_manual',1,'']]],
  ['compiling_20the_20library_43',['Compiling the library',['../compile_guide.html#compile_compile',1,'']]],
  ['config_20file_20package_20support_44',['CMake config-file package support',['../news.html#news_32_cmake',1,'']]],
  ['config_20on_20unix_45',['With makefiles and pkg-config on Unix',['../build_guide.html#build_link_pkgconfig',1,'']]],
  ['configuration_20changes_46',['Configuration changes',['../input_guide.html#joystick_event',1,'Joystick configuration changes'],['../monitor_guide.html#monitor_event',1,'Monitor configuration changes']]],
  ['configuration_20macros_47',['Configuration macros',['../internals_guide.html#internals_config',1,'']]],
  ['conformance_48',['Standards conformance',['../compat_guide.html',1,'']]],
  ['connection_20callback_49',['Joystick connection callback',['../news.html#news_32_joystick',1,'']]],
  ['constants_20in_20version_203_203_50',['New constants in version 3.3',['../news.html#constants_33',1,'']]],
  ['constraints_51',['Hard and soft constraints',['../window_guide.html#window_hints_hard',1,'']]],
  ['content_20scale_52',['Content scale',['../monitor_guide.html#monitor_scale',1,'Content scale'],['../window_guide.html#window_scale',1,'Window content scale']]],
  ['content_20scale_20queries_20for_20dpi_20aware_20rendering_53',['Content scale queries for DPI-aware rendering',['../news.html#content_scale_33',1,'']]],
  ['context_54',['Context',['../quick_guide.html#quick_create_window',1,'Creating a window and context'],['../context_guide.html#context_current',1,'Current context']]],
  ['context_20creation_55',['Error-free context creation',['../news.html#news_32_noerror',1,'']]],
  ['context_20creation_20api_20selection_56',['Run-time context creation API selection',['../news.html#news_32_contextapi',1,'']]],
  ['context_20creation_20extensions_57',['Support for more context creation extensions',['../news.html#glext_33',1,'']]],
  ['context_20creation_20hints_58',['Context creation hints',['../context_guide.html#context_hints',1,'']]],
  ['context_20creation_20support_59',['OSMesa off-screen context creation support',['../news.html#osmesa_33',1,'']]],
  ['context_20current_60',['Making the OpenGL context current',['../quick_guide.html#quick_context_current',1,'']]],
  ['context_20guide_61',['Context guide',['../context_guide.html',1,'']]],
  ['context_20less_20windows_62',['Context-less windows',['../news.html#news_32_noapi',1,'']]],
  ['context_20management_63',['Explicit context management',['../moving_guide.html#moving_context',1,'']]],
  ['context_20object_20sharing_64',['Context object sharing',['../context_guide.html#context_sharing',1,'']]],
  ['context_20objects_65',['Context objects',['../context_guide.html#context_object',1,'']]],
  ['context_20reference_66',['Context reference',['../group__context.html',1,'']]],
  ['context_20related_20attributes_67',['Context related attributes',['../window_guide.html#window_attribs_ctx',1,'']]],
  ['context_20related_20hints_68',['Context related hints',['../window_guide.html#window_hints_ctx',1,'']]],
  ['context_20release_20behaviors_69',['Context release behaviors',['../news.html#news_31_release',1,'']]],
  ['context_2edox_70',['context.dox',['../context_8dox.html',1,'']]],
  ['contexts_71',['Contexts',['../context_guide.html#context_offscreen',1,'Offscreen contexts'],['../context_guide.html#context_less',1,'Windows without contexts']]],
  ['control_72',['Window input focus control',['../news.html#news_32_focus',1,'']]],
  ['coordinate_20systems_73',['Coordinate systems',['../intro_guide.html#coordinate_systems',1,'']]],
  ['creating_20a_20vulkan_20window_20surface_74',['Creating a Vulkan window surface',['../vulkan_guide.html#vulkan_surface',1,'']]],
  ['creating_20a_20window_20and_20context_75',['Creating a window and context',['../quick_guide.html#quick_create_window',1,'']]],
  ['creating_20the_20window_76',['Creating the window',['../vulkan_guide.html#vulkan_window',1,'']]],
  ['creation_77',['Creation',['../input_guide.html#cursor_custom',1,'Custom cursor creation'],['../news.html#news_32_noerror',1,'Error-free context creation'],['../input_guide.html#cursor_standard',1,'Standard cursor creation'],['../window_guide.html#window_creation',1,'Window creation']]],
  ['creation_20api_20selection_78',['Run-time context creation API selection',['../news.html#news_32_contextapi',1,'']]],
  ['creation_20extensions_79',['Support for more context creation extensions',['../news.html#glext_33',1,'']]],
  ['creation_20hints_80',['Creation hints',['../context_guide.html#context_hints',1,'Context creation hints'],['../window_guide.html#window_hints',1,'Window creation hints']]],
  ['creation_20support_81',['OSMesa off-screen context creation support',['../news.html#osmesa_33',1,'']]],
  ['cross_20compilation_20with_20cmake_20and_20mingw_82',['Cross-compilation with CMake and MinGW',['../compile_guide.html#compile_mingw_cross',1,'']]],
  ['current_83',['Making the OpenGL context current',['../quick_guide.html#quick_context_current',1,'']]],
  ['current_20context_84',['Current context',['../context_guide.html#context_current',1,'']]],
  ['cursor_20centering_20window_20hint_85',['Cursor centering window hint',['../news.html#center_cursor_33',1,'']]],
  ['cursor_20creation_86',['Cursor creation',['../input_guide.html#cursor_custom',1,'Custom cursor creation'],['../input_guide.html#cursor_standard',1,'Standard cursor creation']]],
  ['cursor_20destruction_87',['Cursor destruction',['../input_guide.html#cursor_destruction',1,'']]],
  ['cursor_20enter_20leave_20callback_88',['Cursor enter/leave callback',['../news.html#news_30_enterleave',1,'']]],
  ['cursor_20enter_20leave_20events_89',['Cursor enter/leave events',['../input_guide.html#cursor_enter',1,'']]],
  ['cursor_20hover_20window_20attribute_90',['Mouse cursor hover window attribute',['../news.html#cursor_hover_33',1,'']]],
  ['cursor_20images_91',['Custom mouse cursor images',['../news.html#news_31_cursor',1,'']]],
  ['cursor_20mode_92',['Cursor mode',['../input_guide.html#cursor_mode',1,'']]],
  ['cursor_20objects_93',['Cursor objects',['../input_guide.html#cursor_object',1,'']]],
  ['cursor_20position_94',['Cursor position',['../input_guide.html#cursor_pos',1,'Cursor position'],['../news.html#news_31_direct',1,'Direct access for window attributes and cursor position']]],
  ['cursor_20position_20changes_95',['Cursor position changes',['../moving_guide.html#moving_cursorpos',1,'']]],
  ['cursor_20setting_96',['Cursor setting',['../input_guide.html#cursor_set',1,'']]],
  ['cursor_20shapes_97',['Standard cursor shapes',['../group__shapes.html',1,'']]],
  ['custom_20cursor_20creation_98',['Custom cursor creation',['../input_guide.html#cursor_custom',1,'']]],
  ['custom_20mouse_20cursor_20images_99',['Custom mouse cursor images',['../news.html#news_31_cursor',1,'']]]
];
